@@ -2,7 +2,7 @@ use crate::prelude::*;
 use nu_engine::WholeStreamCommand;
 use nu_errors::ShellError;
 use nu_protocol::{
-    dataframe::{NuDataFrame, PolarsData},
+    dataframe::{Column, NuDataFrame},
     Signature, SyntaxShape, UntaggedValue, Value,
 };
 
@@ -34,13 +34,21 @@ impl WholeStreamCommand for DataFrame {
         vec![
             Example {
                 description: "Filter dataframe using a bool mask",
-                example: r#"let mask = ([$true $false] | dataframe to-series);
+                example: r#"let mask = ([$true $false] | dataframe to-df);
     [[a b]; [1 2] [3 4]] | dataframe to-df | dataframe filter-with $mask"#,
-                result: None,
+                result: Some(vec![NuDataFrame::try_from_columns(
+                    vec![
+                        Column::new("a".to_string(), vec![UntaggedValue::int(1).into()]),
+                        Column::new("b".to_string(), vec![UntaggedValue::int(2).into()]),
+                    ],
+                    &Span::default(),
+                )
+                .expect("simple df for test should not fail")
+                .into_value(Tag::default())]),
             },
             Example {
                 description: "Filter dataframe by creating a mask from operation",
-                example: r#"let mask = (([5 6] | dataframe to-series) > 5);
+                example: r#"let mask = (([5 6] | dataframe to-df) > 5);
     [[a b]; [1 2] [3 4]] | dataframe to-df | dataframe filter-with $mask"#,
                 result: None,
             },
@@ -53,29 +61,42 @@ fn command(mut args: CommandArgs) -> Result<OutputStream, ShellError> {
     let value: Value = args.req(0)?;
 
     let series_span = value.tag.span;
-    let series = match value.value {
-        UntaggedValue::DataFrame(PolarsData::Series(series)) => Ok(series),
+    let df = match value.value {
+        UntaggedValue::DataFrame(df) => Ok(df),
         _ => Err(ShellError::labeled_error(
             "Incorrect type",
             "can only add a series to a dataframe",
             value.tag.span,
         )),
     }?;
-
-    let casted = series.as_ref().bool().map_err(|e| {
+    let series = df.as_series(&series_span)?;
+    let casted = series.bool().map_err(|e| {
         parse_polars_error(
             &e,
-            &&series_span,
+            &series_span,
             Some("Perhaps you want to use a series with booleans as mask"),
         )
     })?;
 
-    let df = NuDataFrame::try_from_stream(&mut args.input, &tag.span)?;
+    let (df, df_tag) = NuDataFrame::try_from_stream(&mut args.input, &tag.span)?;
 
     let res = df
         .as_ref()
-        .filter(&casted)
-        .map_err(|e| parse_polars_error::<&str>(&e, &tag.span, None))?;
+        .filter(casted)
+        .map_err(|e| parse_polars_error::<&str>(&e, &df_tag.span, None))?;
 
     Ok(OutputStream::one(NuDataFrame::dataframe_to_value(res, tag)))
 }
+
+#[cfg(test)]
+mod tests {
+    use super::DataFrame;
+    use super::ShellError;
+
+    #[test]
+    fn examples_work_as_expected() -> Result<(), ShellError> {
+        use crate::examples::test_dataframe as test_examples;
+
+        test_examples(DataFrame {})
+    }
+}
